# contributing to pypyr
pypyr is open source. Your contributions are most welcome.

You don't have to code!

- Star the repo on github
- Spread the word on social media
- Let me know of interesting ways *you* are using pypyr, maybe we can make it 
  even better for your purposes.
- Bug reports
- Documentation improvements
- Ideas for next level ninja features
- Code, new features, bug fixes. . .

. . . All are great! ⭐

Please see here for full contribution guide, coding guidelines and
helpful tips to get you started:

<https://pypyr.io/docs/contributing/>
